@@ -1,3 +1,14 @@
+# -*- coding: utf-8 -*-
+
+"""
+gspread.ns
+~~~~~~~~~~
+
+This module contains namespaces used across the project and related
+helper functions.
+
+"""
+
 ATOM_NS = 'http://www.w3.org/2005/Atom'
 SPREADSHEET_NS = 'http://schemas.google.com/spreadsheets/2006'
 
